from setuptools import setup, find_packages

setup(
    name='openCV_movement_detection',
    version='1.1',
    author='Len',
    description='A Python openCV_movement_detection for movement detection with OpenCV.',
    packages=find_packages(),
    install_requires=['opencv-python'],
)
